@@ -53,7 +53,7 @@
 "*installColormap:	True",
 "*programs:								      \
 				maze -root				    \\n\
-  GL: 				superquadrics -root			    \\n\
+- GL: 				superquadrics -root			    \\n\
 				attraction -root			    \\n\
 				blitspin -root				    \\n\
 				greynetic -root				    \\n\
@@ -80,31 +80,31 @@
 				goop -root				    \\n\
 				grav -root				    \\n\
 				ifs -root				    \\n\
-  GL: 				jigsaw -root				    \\n\
+- GL: 				jigsaw -root				    \\n\
 				julia -root				    \\n\
 -				kaleidescope -root			    \\n\
-  GL: 				moebius -root				    \\n\
+- GL: 				moebius -root				    \\n\
 				moire -root				    \\n\
-  GL: 				morph3d -root				    \\n\
+- GL: 				morph3d -root				    \\n\
 				mountain -root				    \\n\
 				munch -root				    \\n\
 				penrose -root				    \\n\
-  GL: 				pipes -root				    \\n\
+- GL: 				pipes -root				    \\n\
 				rd-bomb -root				    \\n\
-  GL: 				rubik -root				    \\n\
+- GL: 				rubik -root				    \\n\
 -				sierpinski -root			    \\n\
 				slip -root				    \\n\
-  GL: 				sproingies -root			    \\n\
+- GL: 				sproingies -root			    \\n\
 				starfish -root				    \\n\
 				strange -root				    \\n\
 				swirl -root				    \\n\
 				triangle -root				    \\n\
 				xjack -root				    \\n\
 				xlyap -root				    \\n\
-  GL: 				atlantis -root				    \\n\
+- GL: 				atlantis -root				    \\n\
 				bsod -root				    \\n\
-  GL: 				bubble3d -root				    \\n\
-  GL: 				cage -root				    \\n\
+- GL: 				bubble3d -root				    \\n\
+- GL: 				cage -root				    \\n\
 -				crystal -root				    \\n\
 				cynosure -root				    \\n\
 				discrete -root				    \\n\
@@ -114,10 +114,10 @@
 - GL: 				glplanet -root				    \\n\
 				interference -root			    \\n\
 				kumppa -root				    \\n\
-  GL: 				lament -root				    \\n\
+- GL: 				lament -root				    \\n\
 				moire2 -root				    \\n\
-  GL: 				sonar -root				    \\n\
-  GL: 				stairs -root				    \\n\
+- GL: 				sonar -root				    \\n\
+- GL: 				stairs -root				    \\n\
 				truchet -root				    \\n\
 -				vidwhacker -root			    \\n\
 				blaster -root				    \\n\
@@ -131,80 +131,80 @@
 				penetrate -root				    \\n\
 				petri -root				    \\n\
 				phosphor -root				    \\n\
-  GL: 				pulsar -root				    \\n\
+- GL: 				pulsar -root				    \\n\
 				ripples -root				    \\n\
 				shadebobs -root				    \\n\
-  GL: 				sierpinski3d -root			    \\n\
+- GL: 				sierpinski3d -root			    \\n\
 				spotlight -root				    \\n\
 				squiral -root				    \\n\
 				wander -root				    \\n\
 -				webcollage -root			    \\n\
 				xflame -root				    \\n\
 				xmatrix -root				    \\n\
-  GL: 				gflux -root				    \\n\
+- GL: 				gflux -root				    \\n\
 -				nerverot -root				    \\n\
 				xrayswarm -root				    \\n\
 				xspirograph -root			    \\n\
-  GL: 				circuit -root				    \\n\
-  GL: 				dangerball -root			    \\n\
+- GL: 				circuit -root				    \\n\
+- GL: 				dangerball -root			    \\n\
 - GL: 				dnalogo -root				    \\n\
-  GL: 				engine -root				    \\n\
-  GL: 				flipscreen3d -root			    \\n\
-  GL: 				gltext -root				    \\n\
-  GL: 				menger -root				    \\n\
-  GL: 				molecule -root				    \\n\
+- GL: 				engine -root				    \\n\
+- GL: 				flipscreen3d -root			    \\n\
+- GL: 				gltext -root				    \\n\
+- GL: 				menger -root				    \\n\
+- GL: 				molecule -root				    \\n\
 				rotzoomer -root				    \\n\
 				speedmine -root				    \\n\
-  GL: 				starwars -root				    \\n\
-  GL: 				stonerview -root			    \\n\
+- GL: 				starwars -root				    \\n\
+- GL: 				stonerview -root			    \\n\
 				vermiculate -root			    \\n\
 				whirlwindwarp -root			    \\n\
 				zoom -root				    \\n\
 				anemone -root				    \\n\
 				apollonian -root			    \\n\
-  GL: 				boxed -root				    \\n\
-  GL: 				cubenetic -root				    \\n\
-  GL: 				endgame -root				    \\n\
+- GL: 				boxed -root				    \\n\
+- GL: 				cubenetic -root				    \\n\
+- GL: 				endgame -root				    \\n\
 				euler2d -root				    \\n\
 				fluidballs -root			    \\n\
-  GL: 				flurry -root				    \\n\
+- GL: 				flurry -root				    \\n\
 - GL: 				glblur -root				    \\n\
-  GL: 				glsnake -root				    \\n\
+- GL: 				glsnake -root				    \\n\
 				halftone -root				    \\n\
-  GL: 				juggler3d -root				    \\n\
-  GL: 				lavalite -root				    \\n\
+- GL: 				juggler3d -root				    \\n\
+- GL: 				lavalite -root				    \\n\
 -				polyominoes -root			    \\n\
-  GL: 				queens -root				    \\n\
+- GL: 				queens -root				    \\n\
 - GL: 				sballs -root				    \\n\
-  GL: 				spheremonics -root			    \\n\
+- GL: 				spheremonics -root			    \\n\
 -				thornbird -root				    \\n\
 				twang -root				    \\n\
 - GL: 				antspotlight -root			    \\n\
 				apple2 -root				    \\n\
-  GL: 				atunnel -root				    \\n\
+- GL: 				atunnel -root				    \\n\
 				barcode -root				    \\n\
-  GL: 				blinkbox -root				    \\n\
-  GL: 				blocktube -root				    \\n\
-  GL: 				bouncingcow -root			    \\n\
+- GL: 				blinkbox -root				    \\n\
+- GL: 				blocktube -root				    \\n\
+- GL: 				bouncingcow -root			    \\n\
 				cloudlife -root				    \\n\
-  GL: 				cubestorm -root				    \\n\
+- GL: 				cubestorm -root				    \\n\
 				eruption -root				    \\n\
-  GL: 				flipflop -root				    \\n\
-  GL: 				flyingtoasters -root			    \\n\
+- GL: 				flipflop -root				    \\n\
+- GL: 				flyingtoasters -root			    \\n\
 				fontglide -root				    \\n\
-  GL: 				gleidescope -root			    \\n\
-  GL: 				glknots -root				    \\n\
-  GL: 				glmatrix -root				    \\n\
+- GL: 				gleidescope -root			    \\n\
+- GL: 				glknots -root				    \\n\
+- GL: 				glmatrix -root				    \\n\
 - GL: 				glslideshow -root			    \\n\
-  GL: 				hypertorus -root			    \\n\
+- GL: 				hypertorus -root			    \\n\
 - GL: 				jigglypuff -root			    \\n\
 				metaballs -root				    \\n\
-  GL: 				mirrorblob -root			    \\n\
+- GL: 				mirrorblob -root			    \\n\
 				piecewise -root				    \\n\
-  GL: 				polytopes -root				    \\n\
+- GL: 				polytopes -root				    \\n\
 				pong -root				    \\n\
 				popsquares -root			    \\n\
-  GL: 				surfaces -root				    \\n\
+- GL: 				surfaces -root				    \\n\
 				xanalogtv -root				    \\n\
 -				abstractile -root			    \\n\
 				anemotaxis -root			    \\n\
@@ -214,44 +214,49 @@
 				interaggregate -root			    \\n\
 				intermomentary -root			    \\n\
 				memscroller -root			    \\n\
-  GL: 				noof -root				    \\n\
+- GL: 				noof -root				    \\n\
 				pacman -root				    \\n\
-  GL: 				pinion -root				    \\n\
-  GL: 				polyhedra -root				    \\n\
+- GL: 				pinion -root				    \\n\
+- GL: 				polyhedra -root				    \\n\
 - GL: 				providence -root			    \\n\
 				substrate -root				    \\n\
 				wormhole -root				    \\n\
 - GL: 				antmaze -root				    \\n\
-  GL: 				boing -root				    \\n\
+- GL: 				boing -root				    \\n\
 				boxfit -root				    \\n\
-  GL: 				carousel -root				    \\n\
+- GL: 				carousel -root				    \\n\
 				celtic -root				    \\n\
-  GL: 				crackberg -root				    \\n\
-  GL: 				cube21 -root				    \\n\
+- GL: 				crackberg -root				    \\n\
+- GL: 				cube21 -root				    \\n\
 				fiberlamp -root				    \\n\
-  GL: 				fliptext -root				    \\n\
-  GL: 				glhanoi -root				    \\n\
-  GL: 				tangram -root				    \\n\
-  GL: 				timetunnel -root			    \\n\
-  GL: 				glschool -root				    \\n\
-  GL: 				topblock -root				    \\n\
-  GL: 				cubicgrid -root				    \\n\
+- GL: 				fliptext -root				    \\n\
+- GL: 				glhanoi -root				    \\n\
+- GL: 				tangram -root				    \\n\
+- GL: 				timetunnel -root			    \\n\
+- GL: 				glschool -root				    \\n\
+- GL: 				topblock -root				    \\n\
+- GL: 				cubicgrid -root				    \\n\
 				cwaves -root				    \\n\
-  GL: 				gears -root				    \\n\
-  GL: 				glcells -root				    \\n\
-  GL: 				lockward -root				    \\n\
+- GL: 				gears -root				    \\n\
+- GL: 				glcells -root				    \\n\
+- GL: 				lockward -root				    \\n\
 				m6502 -root				    \\n\
-  GL: 				moebiusgears -root			    \\n\
-  GL: 				voronoi -root				    \\n\
-  GL: 				hypnowheel -root			    \\n\
-  GL: 				klein -root				    \\n\
+- GL: 				moebiusgears -root			    \\n\
+- GL: 				voronoi -root				    \\n\
+- GL: 				hypnowheel -root			    \\n\
+- GL: 				klein -root				    \\n\
 -				lcdscrub -root				    \\n\
-  GL: 				photopile -root				    \\n\
-  GL: 				skytentacles -root			    \\n\
-  GL: 				rubikblocks -root			    \\n\
-  GL: 				companioncube -root			    \\n\
-  GL: 				hilbert -root				    \\n\
-  GL: 				tronbit -root				    \\n",
+- GL: 				photopile -root				    \\n\
+- GL: 				skytentacles -root			    \\n\
+- GL: 				rubikblocks -root			    \\n\
+- GL: 				companioncube -root			    \\n\
+- GL: 				hilbert -root				    \\n\
+- GL: 				tronbit -root				    \\n\
+- GL: 				geodesic -root				    \\n\
+				hexadrop -root				    \\n\
+- GL: 				kaleidocycle -root			    \\n\
+- GL: 				quasicrystal -root			    \\n\
+- GL: 				unknownpleasures -root			    \\n",
 "XScreenSaver.pointerPollTime:		0:00:05",
 "XScreenSaver.pointerHysteresis:		10",
 "XScreenSaver.initialDelay:		0:00:00",
@@ -340,6 +345,7 @@
 "*hacks.nerverot.name:       NerveRot",
 "*hacks.noseguy.name:        NoseGuy",
 "*hacks.popsquares.name:     PopSquares",
+"*hacks.quasicrystal.name:   QuasiCrystal",
 "*hacks.rd-bomb.name:        RDbomb",
 "*hacks.rdbomb.name:         RDbomb",
 "*hacks.rotzoomer.name:      RotZoomer",
@@ -356,6 +362,7 @@
 "*hacks.timetunnel.name:     TimeTunnel",
 "*hacks.topblock.name:       TopBlock",
 "*hacks.tronbit.name:        TronBit",
+"*hacks.unknownpleasures.name:UnknownPleasures",
 "*hacks.vidwhacker.name:     VidWhacker",
 "*hacks.webcollage.name:     WebCollage",
 "*hacks.whirlwindwarp.name:  WhirlWindWarp",
